from fastapi import (
    APIRouter,
    Body,
    Depends,
    Form,
    HTTPException,
    Request,
    Response,
    status,
)

from fastapi_jwt_auth import AuthJWT

from sqlalchemy.ext.asyncio import AsyncConnection

from api.db.connection.session import get_connection_dep
from api.db.logic.account import get_user_id, update_user_id,get_user_login
from api.services.update_data_validation import update_user_data_changes

from api.schemas.endpoints.account import UserUpdate

from api.services.access_token_validadtion import AccessTokenValidadtion


api_router = APIRouter(
    prefix="/pofile",
    tags=["User accountModel"],
)


@api_router.get("/{user_id}")
async def get_pofile(user_id: int,
                     connection: AsyncConnection = Depends(get_connection_dep),
                     Authorize: AuthJWT = Depends()):

    current_user = AccessTokenValidadtion(Authorize)

    authorize_user = await get_user_login(connection, current_user)
    if authorize_user.id != user_id :
        raise HTTPException(
            status_code=status.HTTP_409_CONFLICT,
            detail="The provided data already exists in the database")


    user = await get_user_id(connection, user_id)

    if user is None:
        raise HTTPException(
            status_code=status.HTTP_404_NOT_FOUND,
            detail="Account not found")

    return user


@api_router.put("/{user_id}")
async def update_pofile(
    user_id: int,
    user_updata: UserUpdate,
    connection: AsyncConnection = Depends(get_connection_dep),
    Authorize: AuthJWT = Depends()
):

    current_user = AccessTokenValidadtion(Authorize)


    authorize_user = await get_user_login(connection, current_user)
    if authorize_user.id != user_id :
        raise HTTPException(
            status_code=status.HTTP_409_CONFLICT,
            detail="The provided data already exists in the database")

    user = await get_user_id(connection, user_id)
    if user is None:
        raise HTTPException(
            status_code=status.HTTP_404_NOT_FOUND,
            detail="Account not found")


    update_values = update_user_data_changes(user_updata,user)

    if update_values is None:
        return user

    await update_user_id(connection, update_values, user)

    user = await get_user_id(connection, user_id)

    return user
